Crate est

Crate est 

Estienne

A digital image generated by an AI of a bearded man reading from a large book in the style of medieval painting.

Rust Project Status: WIP – Initial development is in progress, but there has not yet been a stable, usable release suitable for the public.

Estienne is a simple to use library for interacting with Biblical verses from text. The focus of Estienne is to provide a library for building applications that need to interact with files that contain Biblical scriptures such as lecture notes. No special syntax needs to be used in conjunction with scriptures in order for Estienne to parse the text successfully.

Estienne is still in its initial stages and not ready for use.

The Name

The library is named after Robert Estienne, a French theologian of the early Christian era. He is best remembered for being the first to print the New Testament divided with numbered verses. Read More

The Purpose

The purpose of the library is to provide a simple way to manipulate Biblical verses within a line of text. The API will allow for easy manipulations of the verses, such as:

  • Returning a list of verses found in a line of text
  • Allowing a verses to be:
    • prefixed with arbitrary text
    • suffixed with arbitrary text
    • etc.

Contributing

Contributions are welcomed, but please be aware that the project is still in its prototype phase and large portions of code might change at any moment. Feel free to open an issue if you have any questions or suggestions.

Modules

locales

Structs

Locations
Locations contains the start and end indexes of all the scriptures found in the string.

Enums

Locale

Functions

get_locations
Returns a Location struct containing the start and end index of each scripture found and the original string passed in. This function helps you process the scriptures in whatever manner that you need.
get_scriptures
Returns a vector of the scriptures found in the string passed in.
surround
Adds a prefix and postfix around each scripture found in and returns the modified string.
url
Adds Markdown link syntax around found scriptures to an Online Bible and the modified string is returned. When possible, it will link directly to the scripture being referenced.

Type Aliases

ScriptSlice
ScriptSlice type describes as a tuple the begining and ending index plus one for a scripture found in a string.
ScriptureCollection
The ScriptureCollection is a vector contain scruptures. TODO: Fix docs