pub struct Locations {
pub slices: Vec<ScriptSlice>,
pub string: String,
}Expand description
Locations contains the start and end indexes of all the scriptures found in the string.
Fields
slices: Vec<ScriptSlice>The start and end indexes of all the scriptures found in the string passed in.
string: StringThe original string that was passed in.