ScriptSlice

Type Alias ScriptSlice 

pub type ScriptSlice = (usize, usize);
ScriptSlice type describes as a tuple the begining and ending index plus one for a scripture found in a string.

Take the following string as an example, “Scripture Mathrew 3:16.” The ScriptSlice will be as follows:

  • Start = 10
  • End = 22 (21 + 1)